==> nextcloud-12.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/en_GB.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Shared with you",
    "Shared with others" : "Shared with others",
    "Shared by link" : "Shared by link",
    "Nothing shared with you yet" : "Nothing shared with you yet",
    "Files and folders others share with you will show up here" : "Files and folders others share with you will show up here",
    "Nothing shared yet" : "Nothing shared yet",
    "Files and folders you share will show up here" : "Files and folders you share will show up here",
    "No shared links" : "No shared links",
    "Files and folders you share by link will show up here" : "Files and folders you share by link will show up here",
    "You can upload into this folder" : "You can upload into this folder",
    "No compatible server found at {remote}" : "No compatible server found at {remote}",
    "Invalid server URL" : "Invalid server URL",
    "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
    "Share" : "Share",
    "No expiration date set" : "No expiration date set",
    "Shared by" : "Shared by",
    "Sharing" : "Sharing",
    "File shares" : "File shares",
    "Downloaded via public link" : "Downloaded via public link",
    "Downloaded by {email}" : "Downloaded by {email}",
    "{file} downloaded via public link" : "{file} downloaded via public link",
    "{email} downloaded {file}" : "{email} downloaded {file}",
    "Shared with group {group}" : "Shared with group {group}",
    "Removed share for group {group}" : "Removed share for group {group}",
    "{actor} shared with group {group}" : "{actor} shared with group {group}",
    "{actor} removed share for group {group}" : "{actor} removed share for group {group}",
    "You shared {file} with group {group}" : "You shared {file} with group {group}",
    "You removed group {group} from {file}" : "You removed group {group} from {file}",
    "{actor} shared {file} with group {group}" : "{actor} shared {file} with group {group}",
    "{actor} removed group {group} from {file}" : "{actor} removed group {group} from {file}",
    "Shared as public link" : "Shared as public link",
    "Removed public link" : "Removed public link",
    "Public link expired" : "Public link expired",
    "{actor} shared as public link" : "{actor} shared as public link",
    "{actor} removed public link" : "{actor} removed public link",
    "Public link of {actor} expired" : "Public link of {actor} expired",
    "You shared {file} as public link" : "You shared {file} as public link",
    "You removed public link for {file}" : "You removed public link for {file}",
    "Public link expired for {file}" : "Public link expired for {file}",
    "{actor} shared {file} as public link" : "{actor} shared {file} as public link",
    "{actor} removed public link for {file}" : "{actor} removed public link for {file}",
    "Public link of {actor} for {file} expired" : "Public link of {actor} for {file} expired",
    "{user} accepted the remote share" : "{user} accepted the remote share",
    "{user} declined the remote share" : "{user} declined the remote share",
    "You received a new remote share {file} from {user}" : "You received a new remote share {file} from {user}",
    "{user} accepted the remote share of {file}" : "{user} accepted the remote share of {file}",
    "{user} declined the remote share of {file}" : "{user} declined the remote share of {file}",
    "{user} unshared {file} from you" : "{user} unshared {file} from you",
    "Shared with {user}" : "Shared with {user}",
    "Removed share for {user}" : "Removed share for {user}",
    "{actor} shared with {user}" : "{actor} shared with {user}",
    "{actor} removed share for {user}" : "{actor} removed share for {user}",
    "Shared by {actor}" : "Shared by {actor}",
    "{actor} removed share" : "{actor} removed share",
    "You shared {file} with {user}" : "You shared {file} with {user}",
    "You removed {user} from {file}" : "You removed {user} from {file}",
    "{actor} shared {file} with {user}" : "{actor} shared {file} with {user}",
    "{actor} removed {user} from {file}" : "{actor} removed {user} from {file}",
    "{actor} shared {file} with you" : "{actor} shared {file} with you",
    "{actor} removed you from {file}" : "{actor} removed you from {file}",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "A file or folder shared by mail or by public link was <strong>downloaded</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
    "A file or folder has been <strong>shared</strong>" : "A file or folder has been <strong>shared</strong>",
    "Wrong share ID, share doesn't exist" : "Wrong share ID, share doesn't exist",
    "could not delete share" : "could not delete share",
    "Could not delete share" : "Could not delete share",
    "Please specify a file or folder path" : "Please specify a file or folder path",
    "Wrong path, file/folder doesn't exist" : "Wrong path, file/folder doesn't exist",
    "Could not create share" : "Could not create share",
    "invalid permissions" : "invalid permissions",
    "Please specify a valid user" : "Please specify a valid user",
    "Group sharing is disabled by the administrator" : "Group sharing is disabled by the administrator",
    "Please specify a valid group" : "Please specify a valid group",
    "Public link sharing is disabled by the administrator" : "Public link sharing is disabled by the administrator",
    "Public upload disabled by the administrator" : "Public upload disabled by the administrator",
    "Public upload is only possible for publicly shared folders" : "Public upload is only possible for publicly shared folders",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Sharing %s failed because the back end does not allow shares from type %s",
    "You cannot share to a Circle if the app is not enabled" : "You cannot share to a Circle if the app is not enabled",
    "Please specify a valid circle" : "Please specify a valid circle",
    "Unknown share type" : "Unknown share type",
    "Not a directory" : "Not a directory",
    "Could not lock path" : "Could not lock path",
    "Wrong or no update parameter given" : "Wrong or no update parameter given",
    "Can't change permissions for public share links" : "Can't change permissions for public share links",
    "Cannot increase permissions" : "Cannot increase permissions",
    "%s is publicly shared" : "%s is publicly shared",
    "Share API is disabled" : "Share API is disabled",
    "File sharing" : "File sharing",
    "This share is password-protected" : "This share is password-protected",
    "The password is wrong. Try again." : "The password is wrong. Try again.",
    "Password" : "Password",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Share time" : "Share time",
    "Expiration date" : "Expiration date",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, this link doesn’t seem to work anymore.",
    "Reasons might be:" : "Reasons might be:",
    "the item was removed" : "the item was removed",
    "the link expired" : "the link expired",
    "sharing is disabled" : "sharing is disabled",
    "For more info, please ask the person who sent this link." : "For more info, please ask the person who sent this link.",
    "shared by %s" : "shared by %s",
    "Add to your Nextcloud" : "Add to your Nextcloud",
    "Download" : "Download",
    "Download %s" : "Download %s",
    "Direct link" : "Direct link",
    "Upload files to %s" : "Upload files to %s",
    "Select or drop files" : "Select or drop files",
    "Uploading files…" : "Uploading files…",
    "Uploaded files:" : "Uploaded files:"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/en_GB.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Shared with others",
    "Shared with you" : "Shared with you",
    "Shared by link" : "Shared by link",
    "Nothing shared with you yet" : "Nothing shared with you yet",
    "Files and folders others share with you will show up here" : "Files and folders others share with you will show up here",
    "Nothing shared yet" : "Nothing shared yet",
    "Files and folders you share will show up here" : "Files and folders you share will show up here",
    "No shared links" : "No shared links",
    "Files and folders you share by link will show up here" : "Files and folders you share by link will show up here",
    "Download" : "Download",
    "You can upload into this folder" : "You can upload into this folder",
    "No compatible server found at {remote}" : "No compatible server found at {remote}",
    "Invalid server URL" : "Invalid server URL",
    "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
    "No expiration date set" : "No expiration date set",
    "Shared by" : "Shared by",
    "File shares" : "File shares",
    "Downloaded via public link" : "Downloaded via public link",
    "Downloaded by {email}" : "Downloaded by {email}",
    "{file} downloaded via public link" : "{file} downloaded via public link",
    "{email} downloaded {file}" : "{email} downloaded {file}",
    "Shared with group {group}" : "Shared with group {group}",
    "Removed share for group {group}" : "Removed share for group {group}",
    "{actor} shared with group {group}" : "{actor} shared with group {group}",
    "{actor} removed share for group {group}" : "{actor} removed share for group {group}",
    "You shared {file} with group {group}" : "You shared {file} with group {group}",
    "You removed group {group} from {file}" : "You removed group {group} from {file}",
    "{actor} shared {file} with group {group}" : "{actor} shared {file} with group {group}",
    "{actor} removed group {group} from {file}" : "{actor} removed group {group} from {file}",
    "Shared as public link" : "Shared as public link",
    "Removed public link" : "Removed public link",
    "Public link expired" : "Public link expired",
    "{actor} shared as public link" : "{actor} shared as public link",
    "{actor} removed public link" : "{actor} removed public link",
    "Public link of {actor} expired" : "Public link of {actor} expired",
    "You shared {file} as public link" : "You shared {file} as public link",
    "You removed public link for {file}" : "You removed public link for {file}",
    "Public link expired for {file}" : "Public link expired for {file}",
    "{actor} shared {file} as public link" : "{actor} shared {file} as public link",
    "{actor} removed public link for {file}" : "{actor} removed public link for {file}",
    "Public link of {actor} for {file} expired" : "Public link of {actor} for {file} expired",
    "{user} accepted the remote share" : "{user} accepted the remote share",
    "{user} declined the remote share" : "{user} declined the remote share",
    "You received a new remote share {file} from {user}" : "You received a new remote share {file} from {user}",
    "{user} accepted the remote share of {file}" : "{user} accepted the remote share of {file}",
    "{user} declined the remote share of {file}" : "{user} declined the remote share of {file}",
    "{user} unshared {file} from you" : "{user} unshared {file} from you",
    "Shared with {user}" : "Shared with {user}",
    "Removed share for {user}" : "Removed share for {user}",
    "{actor} shared with {user}" : "{actor} shared with {user}",
    "{actor} removed share for {user}" : "{actor} removed share for {user}",
    "Shared by {actor}" : "Shared by {actor}",
    "{actor} removed share" : "{actor} removed share",
    "You shared {file} with {user}" : "You shared {file} with {user}",
    "You removed {user} from {file}" : "You removed {user} from {file}",
    "{actor} shared {file} with {user}" : "{actor} shared {file} with {user}",
    "{actor} removed {user} from {file}" : "{actor} removed {user} from {file}",
    "{actor} shared {file} with you" : "{actor} shared {file} with you",
    "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "A file or folder shared by mail or by public link was <strong>downloaded</strong>",
    "A file or folder was shared from <strong>another server</strong>" : "A file or folder was shared from <strong>another server</strong>",
    "A file or folder has been <strong>shared</strong>" : "A file or folder has been <strong>shared</strong>",
    "Wrong share ID, share doesn't exist" : "Wrong share ID, share doesn't exist",
    "Could not delete share" : "Could not delete share",
    "Please specify a file or folder path" : "Please specify a file or folder path",
    "Wrong path, file/folder doesn't exist" : "Wrong path, file/folder doesn't exist",
    "Could not create share" : "Could not create share",
    "invalid permissions" : "invalid permissions",
    "Please specify a valid user" : "Please specify a valid user",
    "Group sharing is disabled by the administrator" : "Group sharing is disabled by the administrator",
    "Please specify a valid group" : "Please specify a valid group",
    "Public link sharing is disabled by the administrator" : "Public link sharing is disabled by the administrator",
    "Public upload disabled by the administrator" : "Public upload disabled by the administrator",
    "Public upload is only possible for publicly shared folders" : "Public upload is only possible for publicly shared folders",
    "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
    "You cannot share to a Circle if the app is not enabled" : "You cannot share to a Circle if the app is not enabled",
    "Please specify a valid circle" : "Please specify a valid circle",
    "Unknown share type" : "Unknown share type",
    "Not a directory" : "Not a directory",
    "Could not lock path" : "Could not lock path",
    "Wrong or no update parameter given" : "Wrong or no update parameter given",
    "Can't change permissions for public share links" : "Can't change permissions for public share links",
    "shared by %s" : "shared by %s",
    "Direct link" : "Direct link",
    "Add to your Nextcloud" : "Add to your Nextcloud",
    "Share API is disabled" : "Share API is disabled",
    "File sharing" : "File sharing",
    "Sharing" : "Sharing",
    "Share" : "Share",
    "No entries found in this folder" : "No entries found in this folder",
    "Name" : "Name",
    "Share time" : "Share time",
    "Expiration date" : "Expiration date",
    "Sorry, this link doesn’t seem to work anymore." : "Sorry, this link doesn’t seem to work anymore.",
    "Reasons might be:" : "Reasons might be:",
    "the item was removed" : "the item was removed",
    "the link expired" : "the link expired",
    "sharing is disabled" : "sharing is disabled",
    "For more info, please ask the person who sent this link." : "For more info, please ask the person who sent this link.",
    "Download %s" : "Download %s",
    "Upload files to %s" : "Upload files to %s",
    "Select or drop files" : "Select or drop files",
    "Uploading files…" : "Uploading files…",
    "Uploaded files:" : "Uploaded files:",
    "could not delete share" : "could not delete share"
},
"nplurals=2; plural=(n != 1);");
